# Run Report: Only_VD:all-1epochs


## Train → Grad Norm

![train/grad_norm](train_grad_norm.png)


## Train → Loss

![train/loss](train_loss.png)


## Notes and Insights

Add your notes and insights here.


---

*See [metadata.md](metadata.md) for detailed run information.*
